@@ -1,38 +1,41 @@
-from cli.utils import download_url, parse_dataset_filter, fetch_auth
-from zpy.files import to_pathlib_path
-from table_logger import TableLogger
-import requests
-import logging
 import json
+import logging
+
+import requests
+from table_logger import TableLogger
+from zpy.files import to_pathlib_path
+
+from cli.utils import download_url, fetch_auth, parse_dataset_filter
 
 log = logging.getLogger(__name__)
 
 
 @fetch_auth
-def create_generated_dataset(name, scene_name, config, url, auth_headers):
+def create_generated_dataset(name, sim_name, config, url, auth_headers):
     """ create a dataset on ragnarok """
-    endpoint = f'{url}/api/v1/scenes/'
-    params = {'name': scene_name}
+    endpoint = f'{url}/api/v1/sims/'
+    params = {'name': sim_name}
     r = requests.get(endpoint, params=params, headers=auth_headers)
     if r.status_code != 200:
-        log.warning(f'unable to fetch scenes')
+        log.warning(f'unable to fetch sims')
         return
     response = json.loads(r.text)
     if response['count'] != 1:
-        log.warning(f'unable to find scene with name {scene_name}')
+        log.warning(f'unable to find sim with name {sim_name}')
         return
-    scene = response['results'][0]
+    sim = response['results'][0]
     endpoint = f'{url}/api/v1/generated-data-sets/'
     data = {
-        'scene': scene['id'],
+        'sim': sim['id'],
         'config': json.dumps(config),
         'name': name
     }
     r = requests.post(endpoint, data=data, headers=auth_headers)
     if r.status_code != 201:
-        log.warning(f'Unable to create dataset {name} for scene {scene_name} with config {config}')
+        log.warning(
+            f'Unable to create dataset {name} for sim {sim_name} with config {config}')
         return
-    log.info(f'created dataset {name} for scene {scene_name} with config {config}')
+    log.info(f'created dataset {name} for sim {sim_name} with config {config}')
 
 
 @fetch_auth
@@ -41,11 +44,14 @@ def filter_dataset(dfilter, url, auth_headers):
     dset = []
     field, pattern, regex = parse_dataset_filter(dfilter)
     endpoint = f'{url}/api/v1/uploaded-data-sets/'
-    dset.extend(filter_dataset_url(field, pattern, regex, endpoint, auth_headers))
+    dset.extend(filter_dataset_url(
+        field, pattern, regex, endpoint, auth_headers))
     endpoint = f'{url}/api/v1/generated-data-sets/'
-    dset.extend(filter_dataset_url(field, pattern, regex, endpoint, auth_headers))
+    dset.extend(filter_dataset_url(
+        field, pattern, regex, endpoint, auth_headers))
     endpoint = f'{url}/api/v1/job-data-sets/'
-    dset.extend(filter_dataset_url(field, pattern, regex, endpoint, auth_headers))
+    dset.extend(filter_dataset_url(
+        field, pattern, regex, endpoint, auth_headers))
     return dset
 
 
@@ -91,7 +97,8 @@ def fetch_dataset(name, path, dataset_type, url, auth_headers):
         return
     response = json.loads(r.text)
     if response['count'] != 1:
-        log.warning(f'Unable to find {dataset_type} dataset with name "{name}"')
+        log.warning(
+            f'Unable to find {dataset_type} dataset with name "{name}"')
         return
     dataset = response['results'][0]
     endpoint = f"{url}/api/v1/{dataset['dataset_type']}-data-sets/{dataset['id']}/download"
@@ -105,20 +112,6 @@ def fetch_dataset(name, path, dataset_type, url, auth_headers):
     download_url(response['redirect_link'], output_path)
 
 
-def fetch_datasets():
-    """ fetch all datasets in ragnarok """
-    u_datasets = fetch_uploaded_datasets()
-    g_datasets = fetch_generated_datasets()
-    j_datasets = fetch_job_datasets()
-    tbl = TableLogger(columns='state,type,name,timestamp,id',default_colwidth=30)
-    for d in u_datasets:
-        tbl(d['state'], 'UPLOADED', d['name'], d['created_at'], d['id'])
-    for d in g_datasets:
-        tbl(d['state'], 'GENERATED', d['name'], d['created_at'], d['id'])
-    for d in j_datasets:
-        tbl(d['state'], 'JOB', d['name'], d['created_at'], d['id'])
-
-
 @fetch_auth
 def fetch_uploaded_datasets(url, auth_headers):
     endpoint = f'{url}/api/v1/uploaded-data-sets/'
@@ -147,3 +140,18 @@ def fetch_job_datasets(url, auth_headers):
         log.warning('Unable to fetch job datasets')
         return []
     return json.loads(r.text)['results']
+
+
+def fetch_datasets():
+    """ fetch all datasets in ragnarok """
+    u_datasets = fetch_uploaded_datasets()
+    g_datasets = fetch_generated_datasets()
+    j_datasets = fetch_job_datasets()
+    tbl = TableLogger(columns='state,type,name,timestamp,id',
+                      default_colwidth=30)
+    for d in u_datasets:
+        tbl(d['state'], 'UPLOADED', d['name'], d['created_at'], d['id'])
+    for d in g_datasets:
+        tbl(d['state'], 'GENERATED', d['name'], d['created_at'], d['id'])
+    for d in j_datasets:
+        tbl(d['state'], 'JOB', d['name'], d['created_at'], d['id'])
