@@ -99,8 +99,43 @@ def delete_obj(
     obj = verify(obj)
     select(obj)
     log.debug(f'Removing obj: {obj.name}')
-    bpy.ops.object.delete()
-    # bpy.data.objects.remove(obj, do_unlink=True)
+    # bpy.ops.object.delete()
+    bpy.data.objects.remove(obj, do_unlink=True)
+
+
+def delete_obj_context(
+    obj: Union[bpy.types.Object, str],
+) -> None:
+    """ Alternative way to delete an object.
+
+    Args:
+        obj (Union[bpy.types.Object, str]): Scene object (or it's name)
+    """
+    obj = verify(obj)
+    log.debug(f'Removing obj: {obj.name}')
+    context_remove = bpy.context.copy()
+    context_remove['selected_objects'] = [obj]
+    bpy.ops.object.delete(context_remove)
+
+
+def empty_collection(
+    collection: bpy.types.Collection = None,
+    method: str = "data",
+) -> None:
+    """ Delete all objects in a collection
+
+    Args:
+        collection (bpy.types.Collection, optional): Optional collection to put new object inside of. Defaults to None.
+        method (str, optional): Deletetion method, the values are data and context
+    """
+    if collection and  ( collection in list(bpy.data.collections)):
+        if method == 'data':
+            for obj in collection.all_objects:
+                bpy.data.objects.remove(obj, do_unlink=True)
+        elif method == 'context':
+            context_remove = bpy.context.copy()
+            context_remove['selected_objects'] = collection.all_objects
+            bpy.ops.object.delete(context_remove)
 
 
 def is_inside(
@@ -232,6 +267,8 @@ def segment(
         as_category (bool, optional): Segment as a category, if false will segment as instance. Defaults to False.
         as_single (bool, optional): Segment all child objects as well. Defaults to False.
     """
+    if "use_sculpt_vertex_colors" in dir(bpy.context.preferences.experimental):
+        bpy.context.preferences.experimental.use_sculpt_vertex_colors = True
     obj = verify(obj)
     if color is None:
         color = zpy.color.random_color(output_style='frgb')
@@ -363,22 +400,25 @@ def copy(
 def translate(
     obj: Union[bpy.types.Object, str],
     translation: Union[Tuple[float], mathutils.Vector] = (0, 0, 0),
+    is_absolute: bool = False,
 ) -> None:
     """ Translate an object (in blender units).
 
     Args:
         obj (Union[bpy.types.Object, str]): Scene object (or it's name)
         translation (Union[Tuple[float], mathutils.Vector], optional): Translation vector (x, y, z). Defaults to (0, 0, 0).
+        is_absolute: (bool, optional): The translation vector becomes the absolute world position
+
     """
     obj = verify(obj)
-    view_layer = zpy.blender.verify_view_layer()
-    select(obj)
     log.debug(f'Translating object {obj.name} by {translation}')
     log.debug(f'Before - obj.matrix_world\n{obj.matrix_world}')
     if not isinstance(translation, mathutils.Vector):
         translation = mathutils.Vector(translation)
-    obj.location = obj.location + translation
-    view_layer.update()
+    if is_absolute:
+        obj.location = translation
+    else:
+        obj.location = obj.location + translation
     log.debug(f'After - obj.matrix_world\n{obj.matrix_world}')
 
 
